@@ -1,9 +1,7 @@
 /*
  * Architecture specifics, little endian 32bit
  *
- * $Id: arch.h 127 2005-11-03 01:53:01Z guillem $
- *
- * Copyright (C) 1997-1998 Herbert Duerr
+ * Copyright © 1997-1998 Herbert Duerr
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -24,31 +22,32 @@
 #ifndef LIBFSTT_ARCH_H
 #define LIBFSTT_ARCH_H
 
+// Compiler support
+
+#ifdef __GNUC__
+#define XFSTT_ATTR_UNUSED	__attribute__((unused))
+#else
+#define XFSTT_ATTR_UNUSED
+#endif
+
 // environment specific
 
-#ifdef __i386__
-#  define MSB_BYTE_FIRST	0	// MSB=1, LSB=0
-#  define MSB_BIT_FIRST		0	// MSB=2, LSB=0
-#  define FSBYTEORDER		'l'	// 'l' little endian, 'B' big endian
-#  define LOGSLP		5	// default SCANLINEPAD is 32bits = 1<<5
-					// change it to 3 for some font clients
-#else
+#ifdef WORDS_BIGENDIAN
 #  define MSB_BYTE_FIRST	1
 #  define MSB_BIT_FIRST		2
 #  define FSBYTEORDER		'B'
-#  define LOGSLP		5
+#else
+#  define MSB_BYTE_FIRST	0
+#  define MSB_BIT_FIRST		0
+#  define FSBYTEORDER		'l'
 #endif
 
+// default SCANLINEPAD is 32bits = 1<<5
+// change it to 3 for some font clients
+#  define LOGSLP		5
+
 // architecture specific
 
-typedef unsigned char u8_t;
-typedef unsigned short u16_t;
-typedef unsigned int u32_t;
-
-typedef signed char s8_t;
-typedef signed short s16_t;
-typedef signed int s32_t;
-
 #include <netinet/in.h>
 
 // byte swapping (doing it by ntohl/ntohs works only on little endian CPUs)
@@ -69,16 +68,8 @@ inline int muldiv(int a, int b, int c)
 }
 #endif
 
-
 #ifndef MULDIV
-// 64bit types are only needed for temporary MULDIV results
-#    ifdef __alpha
-typedef long s64_t;
-typedef unsigned long u64_t;
-#    else
-typedef long long s64_t;
-typedef unsigned long long u64_t;
-#    endif
+#  define MULDIV(a, b, c) (int)(((int64_t)(a) * (b) + (c >> 1)) / (c))
 #endif
 
 //=========== add special cases here ==================
