@@ -1,9 +1,7 @@
 /*
  * Utilities for efficient access to the TTFfile
  *
- * $Id: rafile.cc 127 2005-11-03 01:53:01Z guillem $
- *
- * Copyright (C) 1997-1998 Herbert Duerr
+ * Copyright © 1997-1998 Herbert Duerr
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -51,7 +49,7 @@ shrinkMem(void *ptr, int newsize)
 }
 
 void
-deallocMem(void *ptr, int size)
+deallocMem(void *ptr, int size XFSTT_ATTR_UNUSED)
 {
 	free(ptr);
 }
@@ -171,19 +169,24 @@ operator delete(void *ptr)
 #endif /* MEMDEBUG */
 
 
-RandomAccessFile::RandomAccessFile(char *fileName)
+RandomAccessFile::RandomAccessFile(const char *fileName)
 {
 	int fd = open(fileName, O_RDONLY);
 	if (fd <= 0) {
 		debug("Cannot open \"%s\"\n", fileName);
-		ptr = base = 0;
+		ptr = absbase = base = 0;
 		return;
 	}
 	struct stat st;
 	fstat(fd, &st);
 	length = st.st_size;
-	base = (u8_t *)mmap(0L, length, PROT_READ, MAP_SHARED, fd, 0L);
+	base = (uint8_t *)mmap(0L, length, PROT_READ, MAP_SHARED, fd, 0L);
 	close(fd);
+	if (base == MAP_FAILED) {
+		debug("MMap failed '%s'\n", strerror(errno));
+		ptr = absbase = base = 0;
+		return;
+	}
 	ptr = absbase = base;
 }
 
@@ -195,11 +198,11 @@ RandomAccessFile::closeRAFile()
 	}
 }
 
-u32_t
+uint32_t
 RandomAccessFile::calcChecksum()
 {
-	u32_t checksum = 0;
-	u8_t *saveptr = ptr;
+	uint32_t checksum = 0;
+	uint8_t *saveptr = ptr;
 
 	for (int len = length >> 2; --len >= 0;)
 		checksum += readUInt();
