@@ -1,9 +1,7 @@
 /*
  * Head Table
  *
- * $Id: table_head.cc 127 2005-11-03 01:53:01Z guillem $
- *
- * Copyright (C) 1997-1998 Herbert Duerr
+ * Copyright © 1997-1998 Herbert Duerr
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -34,12 +32,8 @@ HeadTable::HeadTable(RandomAccessFile &f, int offset, int length):
 		return;
 	flags = readUShort();
 	emUnits = readUShort();
-#ifdef HAS64BIT_TYPES
 	/* ctime = */ readULong();		// seconds since 1904!!!
 	/* mtime = */ readULong();		// seconds since 1904!!!
-#else
-	seekRelative(16);
-#endif
 	xmin = readSShort();
 	ymin = readSShort();
 	xmax = readSShort();
