@@ -1,9 +1,7 @@
 /*
  * Kerning Table
  *
- * $Id: table_kern.cc 127 2005-11-03 01:53:01Z guillem $
- *
- * Copyright (C) 1997-1998 Herbert Duerr
+ * Copyright © 1997-1998 Herbert Duerr
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -28,7 +26,7 @@ KernTable::KernTable(RandomAccessFile &f, int offset, int length):
 	kernOffset(0)
 {
 	/* version = */ readUShort();
-	s16_t nTables = readSShort();
+	int16_t nTables = readSShort();
 
 	for(; --nTables >= 0; seekRelative(kernLength - 14)) {
 		/* subVersion = */ readUShort();
