@@ -1,9 +1,7 @@
 /*
  * Character Location Table
  *
- * $Id: table_loca.cc 127 2005-11-03 01:53:01Z guillem $
- *
- * Copyright (C) 1997-1998 Herbert Duerr
+ * Copyright © 1997-1998 Herbert Duerr
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -41,7 +39,7 @@ LocaTable::getGlyphOffset(int glyphNo)
 			ofs = -1;
 	} else {
 		seekAbsolute(glyphNo << 1);
-		u16_t ofs16 = readUShort();
+		uint16_t ofs16 = readUShort();
 		if (ofs16 != readUShort())
 			ofs = ofs16 << 1;
 		else
