@@ -1,9 +1,8 @@
 /*
  * Name Table
  *
- * $Id: table_name.cc 127 2005-11-03 01:53:01Z guillem $
- *
- * Copyright (C) 1997-1998 Herbert Duerr
+ * Copyright © 1997-1998 Herbert Duerr
+ * Copyright © 2008 Guillem Jover
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -22,7 +21,6 @@
  */
 
 #include "ttf.h"
-#include <string.h>
 
 NameTable::NameTable(RandomAccessFile &f, int offset, int length):
 	RandomAccessFile(f, offset, length)
@@ -32,8 +30,8 @@ NameTable::NameTable(RandomAccessFile &f, int offset, int length):
 	strBase = readUShort();		// start of string offset
 }
 
-char *
-NameTable::getString(int pfId, int strId, int *pLen)
+string
+NameTable::getString(int pfId, int strId)
 {
 	// name records
 	seekAbsolute(6);
@@ -43,13 +41,13 @@ NameTable::getString(int pfId, int strId, int *pLen)
 		// 1: Macintosh
 		// 2: ISO
 		// 3: MS encoding
-		u16_t platformId = readUShort();
+		uint16_t platformId = readUShort();
 
 		// 3.0 undefined charset
 		// 3.1 UGL charset with unicode indexing
-		/* u16_t encodingId = */ readUShort();
+		/* uint16_t encodingId = */ readUShort();
 
-		/* u16_t languageId = */ readUShort();
+		/* uint16_t languageId = */ readUShort();
 
 		// 0: copyright notice
 		// 1: font family
@@ -59,46 +57,37 @@ NameTable::getString(int pfId, int strId, int *pLen)
 		// 5: version
 		// 6: postscript name
 		// 7: trademark notice
-		u16_t nameId = readUShort();
+		uint16_t nameId = readUShort();
 
-		u16_t strLength = readUShort();
-		u16_t strOffset = readUShort();
+		uint16_t strLength = readUShort();
+		uint16_t strOffset = readUShort();
 
 		if (platformId == pfId && nameId == strId) {
 			char *p = (char *)base + strBase + strOffset;
-#if 0
-			for (int j = 0; j < strLength; ++j)
-				debug("%c", *(p++));
-			debug("\n");
-#endif
-			*pLen = strLength;
-			p = (char *)base + strBase + strOffset;
 
 			if (p <= (char *)base)
 				return 0;
 			if (p >= (char *)base + getLength())
 				return 0;
 
-			char *str = new char [*pLen];
-			memcpy(str, p, *pLen);
-
-			return str;
+			return string(p, strLength);
 		}
 	}
 
 	// hack to convert unicode -> ascii
 	if (pfId == 1) {
-		const char *p = getString(3, strId, pLen);
+		const string p = getString(3, strId);
 
-		if (!p)
+		if (p.empty())
 			return 0;
 
-		*pLen >>= 1;
-		char *convbuf = new char [*pLen];
-		for (int i = *pLen; --i >= 0;)
-			convbuf[i] = p[2 * i + 1];
+		int len = p.size() >> 1;
 
-		delete p;
+		string convbuf;
+		convbuf.reserve(len);
+
+		for (int i = len; --i >= 0;)
+			convbuf[i] = p[2 * i + 1];
 
 		return convbuf;
 	}
