@@ -1,9 +1,8 @@
 /*
  * General handling of *ttf files
  *
- * $Id: ttfont.cc 127 2005-11-03 01:53:01Z guillem $
- *
- * Copyright (C) 1997-1998 Herbert Duerr
+ * Copyright © 1997-1998 Herbert Duerr
+ * Copyright © 2008 Guillem Jover
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -22,11 +21,10 @@
  */
 
 #include "ttf.h"
-#include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
 
-TTFont::TTFont(char *fileName, int infoOnly):
+TTFont::TTFont(const char *fileName, int infoOnly):
 	RandomAccessFile(fileName),
 	nameTable(0), headTable(0), maxpTable(0),
 	cmapTable(0), locaTable(0), glyphTable(0),
@@ -42,17 +40,17 @@ TTFont::TTFont(char *fileName, int infoOnly):
 	if (openError())
 		return;
 
-	/* u32_t version = */ readUInt();
+	/* uint32_t version = */ readUInt();
 	short nTables = readSShort();
-	/* u16_t searchRange = */ readUShort();
-	/* u16_t entrySelector = */ readUShort();
-	/* u16_t rangeShift = */ readUShort();
+	/* uint16_t searchRange = */ readUShort();
+	/* uint16_t entrySelector = */ readUShort();
+	/* uint16_t rangeShift = */ readUShort();
 
 	for (int i = nTables; --i >= 0;) {
 		int name = readUInt();
 		/* int checksum = */ readUInt();
-		u32_t offset = readUInt();
-		u32_t length = readUInt();
+		uint32_t offset = readUInt();
+		uint32_t length = readUInt();
 		if (length == 0)
 			continue;
 		if (offset >= getLength() || offset + length > getLength()) {
@@ -236,25 +234,17 @@ TTFont::getFontInfo(FontInfo *fi)
 			fi->panose[i] = 0;		// any
 	}
 
-	char *faceName;
-	char *p_faceName = nameTable->getString(1, 4, &fi->faceLength);
+	string faceName = nameTable->getString(1, 4);
 
-	if (p_faceName) {
-		faceName = p_faceName;
-	} else {
+	if (faceName.empty())
 		faceName = "Unknown";
-		fi->faceLength = strlen(faceName);
-	}
 
-	if (fi->faceLength > 32)
-		fi->faceLength = 32;
+	if (fi->faceLength > sizeof(fi->faceName))
+		fi->faceLength = sizeof(fi->faceName);
+	else
+		fi->faceLength = faceName.size();
 
-	strncpy(fi->faceName, faceName, fi->faceLength);
-	if (p_faceName)
-		delete faceName;
-
-	if (fi->faceLength < 31)
-		fi->faceName[fi->faceLength] = 0;
+	faceName.copy(fi->faceName, fi->faceLength);
 }
 
 
@@ -326,18 +316,19 @@ TTFont::getGlyphWidth(int mppemx, int glyphNo)
 
 // verify on reference implementation
 int
-TTFont::patchGlyphCode(GlyphTable *g, int glyphNo)
+TTFont::patchGlyphCode(GlyphTable *g XFSTT_ATTR_UNUSED,
+                       int glyphNo XFSTT_ATTR_UNUSED)
 {
 	return 0;
 }
 
 int
-TTFont::checksum(u8_t *buf, int len)
+TTFont::checksum(uint8_t *buf, int len)
 {
 	len = (len + 3) >> 2;
 	int sum = 0;
 
-	for (u8_t *p = buf; --len >= 0; p += 4) {
+	for (uint8_t *p = buf; --len >= 0; p += 4) {
 		int val = (p[0] << 24) + (p[1] << 16) + (p[2] << 8) + p[3];
 		sum += val;
 	}
@@ -348,14 +339,14 @@ TTFont::checksum(u8_t *buf, int len)
 void
 TTFont::updateChecksums()
 {
-	u8_t *buf = base;
-	u8_t *headTable = 0;
+	uint8_t *buf = base;
+	uint8_t *headTable = 0;
 	int nTables = (buf[4] << 8) + buf[5];
 
 	debug("nTables = %d\n", nTables);
 
 	for (int i = 0; i < nTables; ++i) {
-		u8_t *b = &buf[12 + i * 16];
+		uint8_t *b = &buf[12 + i * 16];
 		int name = (b[0] << 24) + (b[1] << 16) + (b[2] << 8) + b[3];
 		int offset = (b[8] << 24) + (b[9] << 16) + (b[10] << 8) + b[11];
 		int length = (b[12] << 24) + (b[13] << 16) + (b[14] << 8) + b[15];
@@ -363,10 +354,10 @@ TTFont::updateChecksums()
 
 		debug("offset = %08X, length = %08X\n", offset, length);
 
-		b[4] = (u8_t)(check >> 24);
-		b[5] = (u8_t)(check >> 16);
-		b[6] = (u8_t)(check >> 8);
-		b[7] = (u8_t)check;
+		b[4] = (uint8_t)(check >> 24);
+		b[5] = (uint8_t)(check >> 16);
+		b[6] = (uint8_t)(check >> 8);
+		b[7] = (uint8_t)check;
 
 		debug("checksum[%d] = %08X\n", i, check);
 
@@ -380,14 +371,14 @@ TTFont::updateChecksums()
 
 	debug("csAdjust = %08X\n", check);
 
-	headTable[8] = (u8_t)(check >> 24);
-	headTable[9] = (u8_t)(check >> 16);
-	headTable[10] = (u8_t)(check >> 8);
-	headTable[11] = (u8_t)check;
+	headTable[8] = (uint8_t)(check >> 24);
+	headTable[9] = (uint8_t)(check >> 16);
+	headTable[10] = (uint8_t)(check >> 8);
+	headTable[11] = (uint8_t)check;
 }
 
 int
-TTFont::write2File(char *filename)
+TTFont::write2File(const char *filename)
 {
 	FILE *fd = fopen(filename, "wb");
 
@@ -401,51 +392,38 @@ TTFont::write2File(char *filename)
 }
 
 
-#include <string>
 #include <cctype>
+#include <algorithm>
+
+static char
+char_tolower(const char c)
+{
+	return std::tolower(c);
+}
 
 // result has to be preset with the category name "-category-",
 // returns "-category-family-weight-slant-setwidth-TT-"
 // XXX: "pixelsize-pointsize-xres-yres-spacing-avgwidth-charset-encoding"
 
-std::string
-TTFont::getXLFDbase(std::string xlfd_templ)
+string
+TTFont::getXLFDbase(string xlfd_templ)
 {
 //#define XLFDEXT "-normal-tt-0-0-0-0-p-0-iso8859-1"
 //#define XLFDEXT "-normal-tt-"
 
-	int lenFamily;
-	char *p_strFamily = nameTable->getString(1, 1, &lenFamily);
-	std::string strFamily;
+	string strFamily = nameTable->getString(1, 1);
+	string strSubFamily = nameTable->getString(1, 2);
 
-	if (p_strFamily) {
-		strFamily = std::string(p_strFamily, lenFamily);
-	} else {
+	if (strFamily.empty())
 		strFamily = "unknown";
-		lenFamily = strFamily.length();
-	}
 
-	int lenSub;
-	char *p_strSubFamily = nameTable->getString(1, 2, &lenSub);
-	std::string strSubFamily;
-
-	if (p_strFamily) {
-		strSubFamily = std::string(p_strSubFamily, lenSub);
-	} else {
+	if (strFamily.empty())
 		strSubFamily = "tt";
-		lenSub = strSubFamily.length();
-	}
 
-	std::string::iterator i;
+	std::replace(strFamily.begin(), strFamily.end(), '-', ' ');
+	std::replace(strSubFamily.begin(), strSubFamily.end(), '-', ' ');
 
-	for (i = strFamily.begin(); i < strFamily.end(); i++)
-		if (*i == '-')
-			*i = ' ';
-	for (i = strSubFamily.begin(); i < strSubFamily.end(); i++)
-		if (*i == '-')
-			*i = ' ';
-
-	std::string xlfd = xlfd_templ + '-' + strFamily;
+	string xlfd = xlfd_templ + '-' + strFamily;
 
 	if (os2Table) {
 		xlfd += (os2Table->selection & 32) ? "-bold" : "-medium";
@@ -457,13 +435,7 @@ TTFont::getXLFDbase(std::string xlfd_templ)
 
 	xlfd += "-normal-" + strSubFamily + '-';
 
-	for (i = xlfd.begin(); i < xlfd.end(); i++)
-		*i = std::tolower(*i);
-
-	if (p_strFamily)
-		delete p_strFamily;
-	if (p_strSubFamily)
-		delete p_strSubFamily;
+	std::transform(xlfd.begin(), xlfd.end(), xlfd.begin(), char_tolower);
 
 	debug("xlfd = \"%s\"\n", xlfd.c_str());
 
