@@ -1,9 +1,7 @@
 /*
  * Header for glyph remapping subsystem
  *
- * $Id: encoding.h 127 2005-11-03 01:53:01Z guillem $
- *
- * Copyright (C) 1998 Herbert Duerr
+ * Copyright © 1998 Herbert Duerr
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -24,21 +22,24 @@
 #ifndef ENCODING_H
 #define ENCODING_H
 
+#include <string>
+
+using std::string;
+
 class Encoding {
 public:
 	virtual ~Encoding() {}
 	virtual int map2unicode(int code) = 0;
 	virtual int hasGlyphs(int /*unicodeRange*/[4]) { return 1; }
 	static void getDefault(Encoding **maps, int maxcodes);
-	static int parse(char *mapnames, Encoding **maps, int maxcodes);
-	static Encoding *find(char *mapname);
+	static int parse(string mapnames, Encoding **maps, int maxcodes);
+	static Encoding *find(string mapname);
 	static Encoding *enumerate(Encoding *iterator);
 
-	const char *strName;
-	const int lenName;
+	const string Name;
 
 protected:
-	Encoding(char *name);
+	Encoding(const string name);
 
 private:
 	static Encoding *first, *last;
