@@ -1,9 +1,7 @@
 /*
  * Show glyphs
  *
- * $Id: showttf.cc 127 2005-11-03 01:53:01Z guillem $
- *
- * Copyright (C) 1997-1998 Herbert Duerr
+ * Copyright © 1997-1998 Herbert Duerr
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -21,6 +19,8 @@
  *
  */
 
+#include "config.h"
+
 #define STARTGLYF	6
 #define DEFAULT_FONT	"times.ttf"
 
@@ -33,7 +33,7 @@
 #include "ttf.h"
 
 #if (MSB_BYTE_FIRST != 1 || MSB_BIT_FIRST != 2)
-	#error "showttf assumes MSB_BYTE_FIRST=1 and MSB_BIT_FIRST=2"
+#warning "showttf assumes MSB_BYTE_FIRST=1 and MSB_BIT_FIRST=2"
 #endif
 
 static Display *display;
@@ -50,10 +50,10 @@ static int black;
 static int white;
 
 static Rasterizer *raster;
-static u8_t *pixmap;
+static uint8_t *pixmap;
 
-#define BMPSIZE 1048*2048
-u8_t *bitmap = 0;
+#define BMPSIZE		1048 * 2048
+uint8_t *bitmap = 0;
 
 #define DEFAULT_WIDTH	200
 #define DEFAULT_HEIGHT	220
@@ -69,7 +69,7 @@ glyph2image(int glyphNo, int size, int angle, XImage *img)
 	static int old_size = 0, old_angle = 0;
 
 	if (!bitmap)
-		bitmap = (u8_t *)allocMem(BMPSIZE);
+		bitmap = (uint8_t *)allocMem(BMPSIZE);
 	if (!bitmap)
 		return;
 
@@ -89,27 +89,26 @@ glyph2image(int glyphNo, int size, int angle, XImage *img)
 	if (length == 0)
 		return;
 
-	
 	if (raster->anti_aliasing <= 0)
 		switch (SCANLINEPAD) {
 		case 8:
 			break;
 		case 16: {
-			u16_t *p = (u16_t *)bitmap;
+			uint16_t *p = (uint16_t *)bitmap;
 			for (int i = length; --i >= 0; ++p)
 				*p = bswaps(*p);
 			}
 			break;
 		case 32: {
-			u32_t *p = (u32_t *)bitmap;
+			uint32_t *p = (uint32_t *)bitmap;
 			for (int i = length; --i >= 0; ++p)
 				*p = bswapl(*p);
 			}
 			break;
 		case 64: {
-			u32_t *p = (u32_t *)bitmap;
+			uint32_t *p = (uint32_t *)bitmap;
 			for (int i = length; --i >= 0; p += 2) {
-					u32_t tmp = p[0];
+					uint32_t tmp = p[0];
 					p[0] = bswapl(p[1]);
 					p[1] = bswapl(tmp);
 				}
@@ -122,12 +121,12 @@ glyph2image(int glyphNo, int size, int angle, XImage *img)
 			pixmap[i] = color[bitmap[i]];
 #ifndef MAGNIFY
 	else if (MAGNIFY) {
-		s8_t *p1 = (s8_t *)bitmap;
-		u8_t *p2 = pixmap;
+		int8_t *p1 = (int8_t *)bitmap;
+		uint8_t *p2 = pixmap;
 		raster->dX *= 8;	// 1 bpp -> 8 bpp
 		for (int h = 0; h < raster->height; ++h) {
 			int cy = h / MAGNIFY;
-			s8_t m;
+			int8_t m;
 			for (int w = 0; w < raster->dX; ++w) {
 				if ((w & 7) == 0)
 					m = *(p1++);
@@ -163,6 +162,7 @@ int
 xAllocColor(int rgb)
 {
 	XColor c;
+
 	c.red = (rgb >> 8) & 0xff00;
 	c.green = rgb & 0xff00;
 	c.blue = (rgb << 8) & 0xff00;
@@ -180,9 +180,9 @@ main(int argc, char** argv)
 		return -1;
 	}
 
-	char *ttFileName = (argc == 2) ? argv[1] : (char *)DEFAULT_FONT;
+	const char *ttFileName = (argc == 2) ? argv[1] : DEFAULT_FONT;
 
-	pixmap = new u8_t[1024 * 1024];
+	pixmap = new uint8_t[1024 * 1024];
 
 	int done = 0;
 
