@@ -1,8 +1,6 @@
 /*
  * TTFN is an alternative to XLFD suited for arbitrarily scalable fonts
  *
- * $Id: ttfn.h 127 2005-11-03 01:53:01Z guillem $
- *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
  * License as published by the Free Software Foundation; either
@@ -53,7 +51,7 @@
 // panose[9]	= bXHeight
 
 typedef struct {
-	u8_t	nameLen;
+	uint8_t	nameLen;
 	char	magic[2];		// magic == "TT"
 	char	charset;		// U=unicode, A=ascii, S=symbol
 	char	panoseMagic;		// 'P'
